@@ -6,8 +6,8 @@
 ;; Author: Joost Kremers <joostkremers@fastmail.fm>
 ;; Maintainer: Joost Kremers <joostkremers@fastmail.fm>
 ;; Created: 2014
-;; Package-Version: 6.7
-;; Package-Revision: 7bfde4e46794
+;; Package-Version: 20250922.1100
+;; Package-Revision: 4a9df6f1b4f3
 ;; Keywords: text bibtex
 ;; URL: https://github.com/joostkremers/parsebib
 ;; Package-Requires: ((emacs "25.1"))
@@ -72,7 +72,7 @@ id is stored in the entry in the special field `=hashid='.")
 ;;
 ;; " # % ' ( ) , = { }
 ;;
-;; Note that parentheses are allowed by BibTex, though, so I won't exclude
+;; Note that parentheses are allowed by BibTeX, though, so I won't exclude
 ;; them here.
 ;;
 ;; Also, keys and identifiers (field and @String names) are distinguished,
@@ -83,9 +83,7 @@ id is stored in the entry in the special field `=hashid='.")
 (defconst parsebib--bibtex-key-regexp "[^\"#%',={} \t\n\f]+" "Regexp describing a licit BibTeX key.")
 (defconst parsebib--bibtex-entry-start "^[ \t]*@" "Regexp describing the start of an entry.")
 
-(defvar parsebib-postprocessing-excluded-fields '("file"
-                                                  "url"
-                                                  "doi")
+(defvar parsebib-postprocessing-excluded-fields '("file" "url" "doi")
   "List of fields that should not be post-processed.")
 
 ;; Cleaning up TeX code is very slow, so we restrict it to those fields for
@@ -851,18 +849,17 @@ See `parsebib-TeX-markup-replacement-alist' and the function
 
 (defvar parsebib-TeX-markup-replacement-alist
   `((parsebib--TeX-replace-command-or-accent
-     ;; This regexp matches any latex command i.e. anything that
-     ;; starts with a backslash. The name of the command which
-     ;; is either a string of alphabetic characters or a single
-     ;; non-alphabetic character is captured by group 1. The command
-     ;; can have a mandatory argument enclosed by braces which is
-     ;; captured by group 2. If the command has no arguments in
-     ;; brackets or braces, the first non-white space letter after
-     ;; the command is captured in group 3. This is to be able to deal
-     ;; with accents.
-     ;; Note that the capturing of arguments in braces is imperfect,
-     ;; because doing it properly requires sexp parsing. It will fail
-     ;; for cases like \command{\anothercommand{an arg}some text}.
+     ;; This regexp matches any latex command, i.e., anything that starts
+     ;; with a backslash. The name of the command, which is either a string
+     ;; of alphabetic characters or a single non-alphabetic character, is
+     ;; captured by group 1. The command can have a mandatory argument
+     ;; enclosed by braces which is captured by group 2. If the command has
+     ;; no arguments in brackets or braces, the first non-white space
+     ;; letter after the command is captured in group 3. This is to be able
+     ;; to deal with accents.  Note that the capturing of arguments in
+     ;; braces is imperfect, because doing it properly requires sexp
+     ;; parsing. It will fail for cases like \command{\anothercommand{an
+     ;; arg}some text}.
      . ,(rx "\\" (group-n 1 (or (1+ letter) nonl))
             (: (* blank) (opt (or (: (* (: "[" (* (not (any "]"))) "]"))
                                      "{" (group-n 2 (0+ (not (any "}")))) (opt "}"))
@@ -899,7 +896,7 @@ and `parsebib-TeX-literal-replacement-alist' respectively.")
          ;; and get the replacement.
          (rep (or acc (alist-get cmd parsebib-TeX-command-replacement-alist nil nil #'equal))))
     (cond
-     ;; If replacement is a function call it with the argument.
+     ;; If replacement is a function, call it with the argument.
      ((functionp rep) (funcall rep arg))
      ;; Otherwise combine the replacement with the argument. The order of combination
      ;; depends on whether the command is an accent or not.
